### ----------------------------------------
### Tick-density model Rstanarm
### NPS tick drag data 2014-2022
### Code created by A. Martin
### Email: alynn.martin89@gmail.com
### ----------------------------------------
### MODEL02


### L O A D   P A C K A G E S

library(rstanarm)
library(rstan)
library(bayesrules)
library(tidyverse)
library(bayesplot)
library(tidybayes)



### L O A D  D A T A

data02 <- read.table(file="XXX.txt")  ## load tabular data using download name




### M O D E L  02

stan_mod02 <- stan_glm(
  
  count ~ phdd + relative_humidity_april + lagged_binned_deer_management * park_id,
  
  data = data02, 
  
  family = neg_binomial_2(link="log"), 
  
  prior_intercept = normal(0, 2.0),
  
  prior = normal(0, 2.0), 
  
  importance_resampling=TRUE, keep_every=10,
  
  chains = 3, iter = 30000*2, seed = 1000
  
  )



###  M O D E L   O U T P U T

## summary

summary(stan_mod02)

coef(stan_mod02)

stan_mod02$coefficients

tidy(stan_mod02, effects = "fixed", conf.int = TRUE, conf.level = 0.95)

tidy(stan_mod02, effects = "ran_vals", conf.int = TRUE, conf.level = 0.95)


## trace plots

trace <- plot(stan_mod02, "trace", pars=(c("(Intercept)", "phdd", "relative_humidity_april")))


## plotting fixed variable effect

plot(stan_mod02, pars =c("(Intercept)", "phdd", "relative_humidity_april"), prob=0.5, prob_outer=0.95)



### P O S T - H O C   A N A L Y S I S 

library(emmeans)

emmeans(stan_mod02, pairwise ~ lagged_binned_deer_management | park_id) 
